#+ELEVENTY_COLLECTIONS: _posts
#+ELEVENTY_BASE_DIR: ~/proj/static-blog/
#+ELEVENTY_CATEGORIES+: emacs
#+ELEVENTY_LAYOUT: layouts/post
#+ELEVENTY_BASE_URL: https://sachachua.com
* org-attaching the latest image from my Supernote via Browse and Access :supernote:org:
:PROPERTIES:
:CUSTOM_ID: supernote-browse
:ID:       20240926T080807.815726
:EXPORT_DATE: 2024-09-26T08:25:54-0400
:EXPORT_ELEVENTY_PERMALINK: /blog/2024/09/org-attaching-the-latest-image-from-my-supernote-via-browse-and-access/
:EXPORT_ELEVENTY_FILE_NAME: blog/2024/09/org-attaching-the-latest-image-from-my-supernote-via-browse-and-access/
:EXPORT_MODIFIED: 2024-09-29T20:32:58-0400
:END:

#+begin_update
[2024-09-29]: Use sketch links when possible. Recolor before cropping so that the grid is removed.
#+end_update

#+CAPTION: Diagram of different ways to get drawings off my Supernote A5X
[[attachment:2024-09-26-01 Supernote A5X Browse and Access %23supernote.png]]

#+begin_my_details Text from sketch
Supernote A5X
- Screen mirroring (pixelated) -> Puppeteer screenshot (or maybe .mjpeg?)
- Browse & Access (HTTP) -> latest file: recognize text, recolor, crop, upload?
- Dropbox/Google Drive (slow) -> batch process: recognize text, recolor, upload

Bonus: Autocropping encourages me to just get stuff out there even if I haven't filled a page

ideas: remove template automatically? I wonder if I can use another color...

2024-09-26-01
#+end_my_details

I want to quickly get drawings from my Supernote A5X into Emacs so that I can include them in blog posts. Dropbox/Google Drive sync is slow because it synchronizes all the files. The Supernote can mirror its screen as an .mjpeg stream. I couldn't figure out how to grab a frame from that, but I did find out how to [[dotemacs:using-puppeteer-to-grab-an-image-from-the-supernote-s-screen-mirror][use Puppeteer to take an screenshot of the Supernote's screen mirror]]. Still, the resulting image is a little pixelated. If I turn on Browse and Access, the Supernote can serve directories and files as webpages. This lets me grab the latest file and process it. I don't often have time to fill a full A5 page with thoughts, so [[dotemacs:embark-image][autocropping]] the image encourages me to get stuff out there instead of holding on to things.

#+begin_src emacs-lisp
(defvar my-supernote-ip-address "192.168.1.221")
(defun my-supernote-get-exported-files ()
	(let ((data (plz 'get (format "http://%s:8089/EXPORT" my-supernote-ip-address)))
				(list))
		(when (string-match "const json = '\\(.*\\)'" data)
			(sort
			 (alist-get 'fileList (json-parse-string (match-string 1 data) :object-type 'alist :array-type 'list))
			 :key (lambda (o) (alist-get 'date o))
			 :lessp 'string<
			 :reverse t))))

(defun my-supernote-org-attach-latest-exported-file ()
	(interactive)
	;; save the file to the screenshot directory
	(let ((info (car (my-supernote-get-exported-files)))
				new-file
				renamed)
		;; delete matching files
		(setq new-file (expand-file-name
										(replace-regexp-in-string " " "%20" (alist-get 'name info) (org-attach-dir))))
		(when (file-exists-p new-file)
			(delete-file new-file))
		(org-attach-attach
		 (format "http://%s:8089%s" my-supernote-ip-address
						 (alist-get 'uri info))
		 nil
		 'url)
		(setq new-file (my-latest-file (org-attach-dir)))
		;; recolor
		(my-sketch-recolor-png new-file)
		;; autocrop that image
		(my-image-autocrop new-file)
		;; possibly rename
		(setq renamed (my-image-recognize-get-new-filename new-file))
		(when renamed
			(setq renamed (expand-file-name renamed (org-attach-dir)))
			(rename-file new-file renamed t)
			(my-image-store renamed) ; file it in my archive
			(setq new-file renamed))
		;; use a sketch link if it has an ID
		(if (string-match "^[0-9][0-9][0-9][0-9]-[0-9][0-9]-[0-9][0-9]-[0-9][0-9] "
											(file-name-base renamed))
				(org-insert-link nil (concat "sketchFull:" (file-name-base renamed)))
			;; insert the link
			(org-insert-link nil (concat "attachment:" (replace-regexp-in-string "#" "%23" (file-name-nondirectory new-file)))))
		(org-redisplay-inline-images)))
#+end_src
